<?php

/**
 * GepParccomunicadoLogic.
 *
 * @package Logic
 * @author  erikasouza
 *
 */
class GepParccomunicadoLogic{


    private $_GepParccomunicadoEntity;
    private $_GepConvocadoreuniaoLogic;


    /**
     * Construtor da classe.
     */
    public function __construct(){
        $this->_GepParccomunicadoEntity  = new GepParccomunicadoEntity();
        $this->_GepConvocadoreuniaoLogic = new GepConvocadoreuniaoLogic();
    }


    /**    ok
     * REtorna o novo codigo da tabela.
     *
     * @param integer $nrorg Numero da Organizacao.
     *
     * @return Ambigous <number, number>
     */
    public static function novoCodigoGepParccomunicado($nrorg){
        $codigo = GepParccomunicadoEntity::novoCodigoGepParccomunicado($nrorg);
        return $codigo;
    }


    /**    OK
     * Insere o parceiro comunicado e forma.
     *
     * @param integer $comunicado               Codigo da comunicacao.
     * @param integer $parceiro                 Codigo do parceiro comunicado escolhido.
     * @param integer $forma                    Forma de comunicacao. 05|02.
     * @param string  $nome_parc_inserido       Nome do parceiro comunicado.
     * @param integer $prefixo_parc_inserido    Prefixo do telefone.
     * @param string  $comunicado_parc_inserido Telefone ou email do parceiro que foi comunicado.
     * @param integer $operador                 Codigo do operador de insercao.
     * @param date    $data                     Data de insercao.
     * @param integer $nrorg                    Numero da organizacao.
     *
     * @return boolean
     */
    public function insereParceiroComunicado(
        $comunicado, $parceiro, $forma, $nome_parc_inserido,
        $prefixo_parc_inserido, $comunicado_parc_inserido, $operador,
        $data, $nrorg
    ){
        $codigo = $this->_GepParccomunicadoEntity->novoCodigoGepParccomunicado($nrorg);
        $insere = $this->_GepParccomunicadoEntity->insereParceiroComunicado(
            $codigo, $comunicado, $parceiro, $forma, $nome_parc_inserido,
            $prefixo_parc_inserido, $comunicado_parc_inserido, $operador,
            $data, $nrorg
        );

        return $insere;
    }


    /**
     * Valida os emails a serem enviados um comunciado.
     *
     * @param string $lista String com uma informacoes em ordem (CODIGO, NOME, EMAIL) separados por -.
     *
     * @return Ambigous <multitype:, multitype:unknown , multitype:unknown Ambigous <> >
     */
    public function validaEmailParceiros($lista){
        $array_lista = explode("\n", $lista);

        $array_retorno = array();
        $i = 0;
        foreach ($array_lista as $dados) {
            if (empty($dados) === true) {
                continue;
            }

            $array_dados = explode(" - ", $dados);

            $valida_email = new Doctrine_Validator_Email();
            $validacao = $valida_email->validate($array_dados[2]);

            if ($validacao === true) {
                $array_retorno[] = array(
                                    'CODIGO' => $array_dados[0],
                                    'NOME'   => $array_dados[1],
                                    'EMAIL'  => $array_dados[2],
                                   );
            } else {
                $array_retorno[]['ERRO'] = array(
                                            'NOME'  => $array_dados[1],
                                            'EMAIL' => $array_dados[2],
                                           );
            }
        }

        return $array_retorno;
    }


    /**
     * Valida a insercao dos parceiros a um comunicado.
     *
     * @param string  $lista         String com uma informacoes em ordem (CODIGO, NOME, EMAIL) separados por -.
     * @param integer $comunicado    Codigo do comunicado.
     * @param integer $oper_inclusao Codigo do operador.
     * @param date    $data          Date.
     * @param integer $nrorg         Numero da organizacao.
     *
     * @return Ambigous <multitype:, string, multitype:unknown >
     */
    public function validaInsercaoParceiros($lista, $comunicado, $oper_inclusao, date $data, $nrorg) {
        $array_enviaemail = array();
        $mensagem = "Erro ao enviar comunicado para: \n";
        $valida = $this->validaEmailParceiros($lista);
        foreach ($valida as $dados) {
            foreach ($dados as $chave => $dado) {
                if ($chave === 'ERRO') {
                    foreach ($dado as $chave_erro => $dados_erro) {
                        if ($chave_erro === 'NOME') {
                            $mensagem .= $dados_erro;
                        }

                        if ($chave_erro === 'EMAIL') {
                             $mensagem .= ' - '.$dados_erro."\n";
                         }

                         $auxiliar = 1;
                    }
               }
            }

            if ($auxiliar === 1) {
                $array_enviaemail['MENSAGEM'] = $mensagem;
            }

            if ($dados['CODIGO'] === null) {
                continue;
            } else {
                if ($dados['CODIGO'] === '000000') {
                    $this->insereParceiroComunicado(
                        $comunicado, null, '02', $dados['NOME'], null, $dados['EMAIL'],
                        $oper_inclusao, $data, $nrorg
                    );
                } else {
                    $this->insereParceiroComunicado(
                        $comunicado, $dados['CODIGO'], '02', null, null, null, $oper_inclusao, $data, $nrorg
                    );
                }

                $array_enviaemail[] = array(
                                       'CODIGO' => $dados['CODIGO'],
                                       'NOME'   => $dados['NOME'],
                                       'EMAIL'  => $dados['EMAIL'],
                                      );
            }
        }

        return $array_enviaemail;
    }


    /**
     * Retorna os parceiros de um comunicado.
     *
     * @param integer $nrorg      Numero da organizacao.
     * @param integer $comunicado Codigo do comunicado.
     *
     * @return Ambigous <Ambigous, boolean, NULL, TkModelEntity>|boolean
     */
    public function retornaParceirosComu($nrorg, $comunicado){
        try {
            $parceiros = $this->_GepParccomunicadoEntity->retornaParceirosComu($nrorg, $comunicado);
            return $parceiros;
        } catch(Exception $e) {
            switch ($e->getCode()){
            case GepParccomunicadoEntity::SEM_REGISTRO:
                return false;
            default:
                tk_warning('Erro desconhecido: '.$e->getMessage());
            }
        }
    }


    /**       ok
     * Salva os convocados de uma reuniao nos parceiros comunicados.
     *
     * @param integer $nrorg      Numero da organizacao.
     * @param integer $reuniao    Codigo da reuniao.
     * @param integer $comunicado Codigo do comunicado.
     * @param integer $operador   Codigo do operador.
     * @param date    $data       Data.
     *
     * @return boolean
     */
    public function salvaConvocadosComunicado($nrorg, $reuniao, $comunicado, $operador, $data){
        $lista_convocados = $this->_GepConvocadoreuniaoLogic->consultaConvocadosPorReuniao($reuniao, $nrorg);
        if ($lista_convocados !== false AND $lista_convocados !== GepParccomunicadoEntity::SEM_REGISTRO) {
            foreach ($lista_convocados as $convocado) {
                $cd_convocado = $convocado->getNrparcoperador();
                $nm_convocado = $convocado->getNmconvocadoreuniao();
                $email_convocado = $convocado->getDsemailconvocado();

                $this->insereParceiroComunicado(
                    $comunicado, $cd_convocado, '05', $nm_convocado, null,
                    $email_convocado, $operador, $data, $nrorg
                );
            }

            return true;
        } else {
            return false;
        }
    }


}